## Copyright 2022 United States Amry Cyber School
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##    http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.

{% set role = grains['role'] %}

include:
  - formulas/filebeat/install

/etc/filebeat/config:
  file.directory:
    - makedirs: True
    - require:
      - pkg: filebeat-agent

filebeat_modules:
  file.managed:
    - user: root
    - group: root
    - mode: '0644'
    - names:
      - /etc/filebeat/modules.d/auditd.yml:
        - source: salt://formulas/filebeat/modules/auditd.yml
      - /etc/filebeat/modules.d/system.yml:
        - source: salt://formulas/filebeat/modules/system.yml
{% if role in ['mysql','rabbit','haproxy'] %}
      - /etc/filebeat/modules.d/{{ role }}.yml:
        - source: salt://formulas/filebeat/modules/{{ role  }}.yml
{% endif %}
    - require:
      - pkg: filebeat-agent

/etc/filebeat/filebeat.yml:
  file.managed:
    - source: salt://formulas/filebeat/files/filebeat.yml
    - mode: '0600'
    - require:
      - pkg: filebeat-agent

logstash_certificates:
  file.managed:
    - user: root
    - group: root
    - mode: '0644'
    - names:
      - /etc/filebeat/config/admin.pem:
        - contents_pillar: filebeat_certificate
      - /etc/filebeat/config/root-ca.pem:
        - contents_pillar: filebeat_ca_certificate
    - require:
      - file: /etc/filebeat/config

/etc/filebeat/config/admin-key.pem:
  file.managed:
    - user: root
    - group: root
    - mode: '0640'
    - contents_pillar: filebeat_priv_key
    - require:
      - file: /etc/filebeat/config

/etc/filebeat/inputs.d/{{ role }}.yml:
  file.managed:
    - makedirs: True
    - source: salt://formulas/filebeat/inputs/{{ role }}.yml

filebeat:
  service.running:
    - full_restart: True
    - watch:
      - file: /etc/filebeat/inputs.d/{{ role }}.yml
      - file: /etc/filebeat/config/*
